ams.system.System
=================

.. currentmodule:: ams.system

.. autoclass:: System

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~System.add
       
       
          ~System.as_dict
       
       
          ~System.calc_pu_coeff
       
       
          ~System.call_models
       
       
          ~System.collect_config
       
       
          ~System.collect_ref
       
       
          ~System.connectivity
       
       
          ~System.e_clear
       
       
          ~System.f_update
       
       
          ~System.fg_to_dae
       
       
          ~System.find_devices
       
       
          ~System.find_models
       
       
          ~System.from_ipysheet
       
       
          ~System.g_islands
       
       
          ~System.g_update
       
       
          ~System.get_z
       
       
          ~System.import_groups
       
       
          ~System.import_models
       
       
          ~System.import_routines
       
       
          ~System.import_types
       
       
          ~System.init
       
       
          ~System.j_islands
       
       
          ~System.j_update
       
       
          ~System.l_update_eq
       
       
          ~System.l_update_var
       
       
          ~System.link_ext_param
       
       
          ~System.precompile
       
       
          ~System.prepare
       
       
          ~System.reload
       
       
          ~System.remove_pycapsule
       
       
          ~System.report
       
       
          ~System.reset
       
       
          ~System.s_update_post
       
       
          ~System.s_update_var
       
       
          ~System.save_config
       
       
          ~System.set_address
       
       
          ~System.set_config
       
       
          ~System.set_dae_names
       
       
          ~System.set_output_subidx
       
       
          ~System.set_var_arrays
       
       
          ~System.setup
       
       
          ~System.store_adder_setter
       
       
          ~System.store_existing
       
       
          ~System.store_no_check_init
       
       
          ~System.store_sparse_pattern
       
       
          ~System.store_switch_times
       
       
          ~System.summary
       
       
          ~System.supported_models
       
       
          ~System.supported_routines
       
       
          ~System.switch_action
       
       
          ~System.to_andes
       
       
          ~System.to_ipysheet
       
       
          ~System.undill
       
       
          ~System.vars_to_dae
       
       
          ~System.vars_to_models
       
   
   

   
   
   